@@ -89,6 +89,7 @@ times<-times[times<maxtimes]
 Ntimes <- length(times); 
 ## }}}
 
+stop("Under development, not working yet\n"); 
 if (is.null(cause)) stop(" cause must be given\n"); 
 
 ## {{{ censoring and estimator
@@ -147,8 +148,9 @@ Ut<-matrix(0,Ntimes,pg+1); simUt<-matrix(0,antsim,pg);
 loglike<-0; 
 ## }}}
 
-#cat("Generalised Proportional odds model \n"); 
-
+###cat("Generalised Proportional odds model \n"); 
+###print(head(desX)); 
+###print(head(desZ)); 
 
 ## {{{ C-call
 nparout<- .C("Gpropoddssubdist",
